@@ -1,4 +1,7 @@
 """Internationalisation tests."""
+
+from __future__ import annotations
+
 import datetime as dt
 import importlib
 
@@ -8,7 +11,7 @@ from freezegun import freeze_time
 import humanize
 
 with freeze_time("2020-02-02"):
-    NOW = dt.datetime.now()
+    NOW = dt.datetime.now(tz=dt.timezone.utc)
 
 
 @freeze_time("2020-02-02")
@@ -52,6 +55,8 @@ def test_intcomma() -> None:
 
         humanize.i18n.activate("fr_FR")
         assert humanize.intcomma(number) == "10 000 000"
+        assert humanize.intcomma(1_234_567.89) == "1 234 567.89"
+        assert humanize.intcomma("1 234 567.89") == "1 234 567.89"
 
         humanize.i18n.activate("pt_BR")
         assert humanize.intcomma(number) == "10.000.000"
@@ -153,20 +158,20 @@ def test_ordinal_genders(
         humanize.i18n.deactivate()
 
 
-def test_default_locale_path_defined__file__() -> None:
+def test_default_locale_path_defined__spec__() -> None:
     i18n = importlib.import_module("humanize.i18n")
     assert i18n._get_default_locale_path() is not None
 
 
-def test_default_locale_path_null__file__() -> None:
+def test_default_locale_path_none__spec__(monkeypatch: pytest.MonkeyPatch) -> None:
     i18n = importlib.import_module("humanize.i18n")
-    i18n.__file__ = None
+    monkeypatch.setattr(i18n, "__spec__", None)
     assert i18n._get_default_locale_path() is None
 
 
-def test_default_locale_path_undefined__file__() -> None:
+def test_default_locale_path_undefined__file__(monkeypatch: pytest.MonkeyPatch) -> None:
     i18n = importlib.import_module("humanize.i18n")
-    del i18n.__file__
+    monkeypatch.delattr(i18n, "__spec__")
     assert i18n._get_default_locale_path() is None
 
 
@@ -176,18 +181,54 @@ class TestActivate:
         " 'locale' folder. You need to pass the path explicitly."
     )
 
-    def test_default_locale_path_null__file__(self) -> None:
+    def test_default_locale_path_null__spec__(
+        self, monkeypatch: pytest.MonkeyPatch
+    ) -> None:
         i18n = importlib.import_module("humanize.i18n")
-        i18n.__file__ = None
+        monkeypatch.setattr(i18n, "__spec__", None)
 
         with pytest.raises(Exception) as excinfo:
             i18n.activate("ru_RU")
         assert str(excinfo.value) == self.expected_msg
 
-    def test_default_locale_path_undefined__file__(self) -> None:
+    def test_default_locale_path_undefined__spec__(
+        self, monkeypatch: pytest.MonkeyPatch
+    ) -> None:
         i18n = importlib.import_module("humanize.i18n")
-        del i18n.__file__
+        monkeypatch.delattr(i18n, "__spec__")
 
         with pytest.raises(Exception) as excinfo:
             i18n.activate("ru_RU")
         assert str(excinfo.value) == self.expected_msg
+
+    @freeze_time("2020-02-02")
+    def test_en_locale(self) -> None:
+        three_seconds = NOW - dt.timedelta(seconds=3)
+        test_str = humanize.naturaltime(three_seconds)
+
+        humanize.i18n.activate("en_US")
+        assert test_str == humanize.naturaltime(three_seconds)
+
+        humanize.i18n.activate("en_GB")
+        assert test_str == humanize.naturaltime(three_seconds)
+
+        humanize.i18n.deactivate()
+
+    @freeze_time("2020-02-02")
+    def test_none_locale(self) -> None:
+        three_seconds = NOW - dt.timedelta(seconds=3)
+
+        try:
+            humanize.i18n.activate("fr")
+            assert humanize.naturaltime(three_seconds) == "il y a 3 secondes"
+
+            humanize.i18n.activate(None)
+            test_str = humanize.naturaltime(three_seconds)
+            assert test_str == "3 seconds ago"
+        except FileNotFoundError:
+            pytest.skip("Generate .mo with scripts/generate-translation-binaries.sh")
+
+        finally:
+            humanize.i18n.deactivate()
+
+        assert test_str == humanize.naturaltime(three_seconds)
